########################################################################
wrap_technote Python package documentation
########################################################################

This documentation is about the Python package wrap_technote. This package provides code
to run the annual water resource reporting code at DEW.

The source code for wrap_technote is kept at `GitLab
<https://gitlab.com/dew-waterscience/wrap_technote>`_ together with an issue tracker and an
archive of all releases. The repository is not accessible to the public, so please contact
`Kent Inverarity <mailto:Kent.Inverarity@sa.gov.au>`_ for access to the code repository.
You will need a free GitLab.com account in order to view this documentation and access
the source code and issue tracker.


.. toctree::
   :caption: Other documentation
   
   Other versions <../index.html#http://>
   Other packages <../../index.html#http://>

.. toctree::
   :maxdepth: 3
   :caption: Introduction

   installation
   reporting
   changelog

.. toctree::
   :maxdepth: 3
   :caption: Examples

   query_and_validate_water_levels.ipynb
   salinity_indicators.ipynb

.. toctree::
   :maxdepth: 3
   :caption: Running the analysis

   analysis-WL
   analysis-TDS
   analysis-RF
   analysis-SUMMARIES

.. toctree::
   :maxdepth: 3
   :caption: Data

   data-tables

.. toctree::
   :maxdepth: 3
   :caption: Configuration

   configuration
   rainfall
   groundwater-resource-definitions
   
.. toctree::
   :maxdepth: 3
   :caption: Code documentation

   apidocs

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
